Crate runa_tui

Crate runa_tui 

Internal library crate for runa.

The shipped application is the rn binary (src/main.rs).

This library exists to share code between targets (binary, tests) and to keep modules organized. This API is only used to build the rn binary and is not considered a library for external use.

Modules

app
Application module.
config
Configuration options for runa
core
Core runtime logic for runa.
ui
Terminal User Interface rendering logic.
utils
Miscellaneous utility functions for runa.