Crate runa_tui

Crate runa_tui 

Modules

app
Application State and main controller module for runa.
cli
Command-line argument parsing and help for runa.
config
Configuration options for runa
file_manager
File and directory browsing logic for runa.
formatter
Sorting, filtering, and display formatting for file entries in runa.
keymap
Key mapping and action dispatch system for runa
terminal
Terminal rendering and event loop for runa.
ui
Terminal User Interface rendering logic.
utils
Misc utilits functions for color parsing and external editor for opening files with.
worker
Worker thread for the runa core operations.